@@ -14,6 +14,7 @@ from typing import (
     List,
     MutableMapping,
     Optional,
+    Sequence,
     Tuple,
     Union,
 )
@@ -42,7 +43,6 @@ from cmdstanpy.utils import (
     get_logger,
     scan_generated_quantities_csv,
 )
-
 from .metadata import InferenceMetadata
 from .runset import RunSet
 
@@ -77,31 +77,34 @@ class CmdStanMCMC:
         assert isinstance(
             sampler_args, SamplerArgs
         )  # make the typechecker happy
-        iter_sampling = sampler_args.iter_sampling
-        if iter_sampling is None:
-            self._iter_sampling = _CMDSTAN_SAMPLING
-        else:
-            self._iter_sampling = iter_sampling
-        iter_warmup = sampler_args.iter_warmup
-        if iter_warmup is None:
-            self._iter_warmup = _CMDSTAN_WARMUP
-        else:
-            self._iter_warmup = iter_warmup
-        thin = sampler_args.thin
-        if thin is None:
-            self._thin: int = _CMDSTAN_THIN
-        else:
-            self._thin = thin
+        self._iter_sampling: int = _CMDSTAN_SAMPLING
+        if sampler_args.iter_sampling is not None:
+            self._iter_sampling = sampler_args.iter_sampling
+        self._iter_warmup: int = _CMDSTAN_WARMUP
+        if sampler_args.iter_warmup is not None:
+            self._iter_warmup = sampler_args.iter_warmup
+        self._thin: int = _CMDSTAN_THIN
+        if sampler_args.thin is not None:
+            self._thin = sampler_args.thin
         self._is_fixed_param = sampler_args.fixed_param
         self._save_warmup = sampler_args.save_warmup
         self._sig_figs = runset._args.sig_figs
+
         # info from CSV values, instantiated lazily
+        self._draws: np.ndarray = np.array(())
+        # only valid when not is_fixed_param
         self._metric: np.ndarray = np.array(())
         self._step_size: np.ndarray = np.array(())
-        self._draws: np.ndarray = np.array(())
+        self._divergences: np.ndarray = np.zeros(self.runset.chains, dtype=int)
+        self._max_treedepths: np.ndarray = np.zeros(
+            self.runset.chains, dtype=int
+        )
+
         # info from CSV initial comments and header
         config = self._validate_csv_files()
         self._metadata: InferenceMetadata = InferenceMetadata(config)
+        if not self._is_fixed_param:
+            self._check_sampler_diagnostics()
 
     def __repr__(self) -> str:
         repr = 'CmdStanMCMC: model={} chains={}{}'.format(
@@ -117,6 +120,14 @@ class CmdStanMCMC:
         # TODO - hamiltonian, profiling files
         return repr
 
+    def __getattr__(self, attr: str) -> np.ndarray:
+        """Synonymous with ``fit.stan_variable(attr)"""
+        try:
+            return self.stan_variable(attr)
+        except ValueError as e:
+            # pylint: disable=raise-missing-from
+            raise AttributeError(*e.args)
+
     @property
     def chains(self) -> int:
         """Number of chains."""
@@ -162,13 +173,15 @@ class CmdStanMCMC:
     @property
     def metric_type(self) -> Optional[str]:
         """
-        Metric type used for adaptation, either 'diag_e' or 'dense_e'.
+        Metric type used for adaptation, either 'diag_e' or 'dense_e', according
+        to CmdStan arg 'metric'.
         When sampler algorithm 'fixed_param' is specified, metric_type is None.
         """
-        if self._is_fixed_param:
-            return None
-        # cmdstan arg name
-        return self._metadata.cmdstan_config['metric']  # type: ignore
+        return (
+            self._metadata.cmdstan_config['metric']
+            if not self._is_fixed_param
+            else None
+        )
 
     @property
     def metric(self) -> Optional[np.ndarray]:
@@ -183,8 +196,7 @@ class CmdStanMCMC:
                 'Unit diagnonal metric, inverse mass matrix size unknown.'
             )
             return None
-        if self._draws.shape == (0,):
-            self._assemble_draws()
+        self._assemble_draws()
         return self._metric
 
     @property
@@ -193,11 +205,8 @@ class CmdStanMCMC:
         Step size used by sampler for each chain.
         When sampler algorithm 'fixed_param' is specified, step size is None.
         """
-        if self._is_fixed_param:
-            return None
-        if self._step_size.shape == (0,):
-            self._assemble_draws()
-        return self._step_size
+        self._assemble_draws()
+        return self._step_size if not self._is_fixed_param else None
 
     @property
     def thin(self) -> int:
@@ -206,6 +215,23 @@ class CmdStanMCMC:
         """
         return self._thin
 
+    @property
+    def divergences(self) -> Optional[np.ndarray]:
+        """
+        Per-chain total number of post-warmup divergent iterations.
+        When sampler algorithm 'fixed_param' is specified, returns None.
+        """
+        return self._divergences if not self._is_fixed_param else None
+
+    @property
+    def max_treedepths(self) -> Optional[np.ndarray]:
+        """
+        Per-chain total number of post-warmup iterations where the NUTS sampler
+        reached the maximum allowed treedepth.
+        When sampler algorithm 'fixed_param' is specified, returns None.
+        """
+        return self._max_treedepths if not self._is_fixed_param else None
+
     def draws(
         self, *, inc_warmup: bool = False, concat_chains: bool = False
     ) -> np.ndarray:
@@ -254,6 +280,7 @@ class CmdStanMCMC:
         Checks that Stan CSV output files for all chains are consistent
         and returns dict containing config and column names.
 
+        Tabulates sampling iters which are divergent or at max treedepth
         Raises exception when inconsistencies detected.
         """
         dzero = {}
@@ -267,6 +294,9 @@ class CmdStanMCMC:
                     save_warmup=self._save_warmup,
                     thin=self._thin,
                 )
+                if not self._is_fixed_param:
+                    self._divergences[i] = dzero['ct_divergences']
+                    self._max_treedepths[i] = dzero['ct_max_treedepth']
             else:
                 drest = check_sampler_csv(
                     path=self.runset.csv_files[i],
@@ -303,13 +333,43 @@ class CmdStanMCMC:
                                 drest[key],
                             )
                         )
+                if not self._is_fixed_param:
+                    self._divergences[i] = drest['ct_divergences']
+                    self._max_treedepths[i] = drest['ct_max_treedepth']
         return dzero
 
+    def _check_sampler_diagnostics(self) -> None:
+        """
+        Warn if any iterations ended in divergences or hit maxtreedepth.
+        """
+        if np.any(self._divergences) or np.any(self._max_treedepths):
+            diagnostics = ['Some chains may have failed to converge.']
+            ct_iters = self.metadata.cmdstan_config['num_samples']
+            for i in range(self.runset._chains):
+                if self._divergences[i] > 0:
+                    diagnostics.append(
+                        f'Chain {i + 1} had {self._divergences[i]} '
+                        'divergent transitions '
+                        f'({((self._divergences[i]/ct_iters)*100):.1f}%)'
+                    )
+                if self._max_treedepths[i] > 0:
+                    diagnostics.append(
+                        f'Chain {i + 1} had {self._max_treedepths[i]} '
+                        'iterations at max treedepth '
+                        f'({((self._max_treedepths[i]/ct_iters)*100):.1f}%)'
+                    )
+            diagnostics.append(
+                'Use function "diagnose()" to see further information.'
+            )
+            get_logger().warning('\n\t'.join(diagnostics))
+
     def _assemble_draws(self) -> None:
         """
         Allocates and populates the step size, metric, and sample arrays
         by parsing the validated stan_csv files.
         """
+        if self._draws.shape != (0,):
+            return
         num_draws = self.num_draws_sampling
         sampling_iter_start = 0
         if self._save_warmup:
@@ -382,8 +442,8 @@ class CmdStanMCMC:
 
     def summary(
         self,
-        percentiles: Optional[List[int]] = None,
-        sig_figs: Optional[int] = None,
+        percentiles: Sequence[int] = (5, 50, 95),
+        sig_figs: int = 6,
     ) -> pd.DataFrame:
         """
         Run cmdstan/bin/stansummary over all output CSV files, assemble
@@ -393,8 +453,9 @@ class CmdStanMCMC:
         quantities variables listed in the order in which they were declared
         in the Stan program.
 
-        :param percentiles: Ordered non-empty list of percentiles to report.
-            Must be integers from (1, 99), inclusive.
+        :param percentiles: Ordered non-empty sequence of percentiles to report.
+            Must be integers from (1, 99), inclusive. Defaults to
+            ``(5, 50, 95)``
 
         :param sig_figs: Number of significant figures to report.
             Must be an integer between 1 and 18.  If unspecified, the default
@@ -405,40 +466,38 @@ class CmdStanMCMC:
 
         :return: pandas.DataFrame
         """
-        percentiles_str = '--percentiles=5,50,95'
-        if percentiles is not None:
-            if len(percentiles) == 0:
+
+        if len(percentiles) == 0:
+            raise ValueError(
+                'Invalid percentiles argument, must be ordered'
+                ' non-empty list from (1, 99), inclusive.'
+            )
+        cur_pct = 0
+        for pct in percentiles:
+            if pct > 99 or not pct > cur_pct:
                 raise ValueError(
-                    'Invalid percentiles argument, must be ordered'
+                    'Invalid percentiles spec, must be ordered'
                     ' non-empty list from (1, 99), inclusive.'
                 )
-            cur_pct = 0
-            for pct in percentiles:
-                if pct > 99 or not pct > cur_pct:
-                    raise ValueError(
-                        'Invalid percentiles spec, must be ordered'
-                        ' non-empty list from (1, 99), inclusive.'
-                    )
-                cur_pct = pct
-            percentiles_str = '='.join(
-                ['--percentiles', ','.join([str(x) for x in percentiles])]
+            cur_pct = pct
+        percentiles_str = (
+            f"--percentiles= {','.join(str(x) for x in percentiles)}"
+        )
+
+        if not isinstance(sig_figs, int) or sig_figs < 1 or sig_figs > 18:
+            raise ValueError(
+                'Keyword "sig_figs" must be an integer between 1 and 18,'
+                ' found {}'.format(sig_figs)
             )
-        sig_figs_str = '--sig_figs=2'
-        if sig_figs is not None:
-            if not isinstance(sig_figs, int) or sig_figs < 1 or sig_figs > 18:
-                raise ValueError(
-                    'Keyword "sig_figs" must be an integer between 1 and 18,'
-                    ' found {}'.format(sig_figs)
-                )
-            csv_sig_figs = self._sig_figs or 6
-            if sig_figs > csv_sig_figs:
-                get_logger().warning(
-                    'Requesting %d significant digits of output, but CSV files'
-                    ' only have %d digits of precision.',
-                    sig_figs,
-                    csv_sig_figs,
-                )
-            sig_figs_str = '--sig_figs=' + str(sig_figs)
+        csv_sig_figs = self._sig_figs or 6
+        if sig_figs > csv_sig_figs:
+            get_logger().warning(
+                'Requesting %d significant digits of output, but CSV files'
+                ' only have %d digits of precision.',
+                sig_figs,
+                csv_sig_figs,
+            )
+        sig_figs_str = f'--sig_figs={sig_figs}'
         cmd_path = os.path.join(
             cmdstan_path(), 'bin', 'stansummary' + EXTENSION
         )
@@ -619,7 +678,7 @@ class CmdStanMCMC:
 
     def stan_variable(
         self,
-        var: Optional[str] = None,
+        var: str,
         inc_warmup: bool = False,
     ) -> np.ndarray:
         """
@@ -647,6 +706,9 @@ class CmdStanMCMC:
         and the sample consists of 4 chains with 1000 post-warmup draws,
         this function will return a numpy.ndarray with shape (4000,3,3).
 
+        This functionaltiy is also available via a shortcut using ``.`` -
+        writing ``fit.a`` is a synonym for ``fit.stan_variable("a")``
+
         :param var: variable name
 
         :param inc_warmup: When ``True`` and the warmup draws are present in
@@ -660,10 +722,12 @@ class CmdStanMCMC:
         CmdStanVB.stan_variable
         CmdStanGQ.stan_variable
         """
-        if var is None:
-            raise ValueError('No variable name specified.')
         if var not in self._metadata.stan_vars_dims:
-            raise ValueError('Unknown variable name: {}'.format(var))
+            raise ValueError(
+                f'Unknown variable name: {var}\n'
+                'Available variables are '
+                + ", ".join(self._metadata.stan_vars_dims)
+            )
         if self._draws.shape == (0,):
             self._assemble_draws()
         draw1 = 0
@@ -767,6 +831,14 @@ class CmdStanGQ:
         )
         return repr
 
+    def __getattr__(self, attr: str) -> np.ndarray:
+        """Synonymous with ``fit.stan_variable(attr)"""
+        try:
+            return self.stan_variable(attr)
+        except ValueError as e:
+            # pylint: disable=raise-missing-from
+            raise AttributeError(*e.args)
+
     def _validate_csv_files(self) -> Dict[str, Any]:
         """
         Checks that Stan CSV output files for all chains are consistent
@@ -1130,7 +1202,7 @@ class CmdStanGQ:
 
     def stan_variable(
         self,
-        var: Optional[str] = None,
+        var: str,
         inc_warmup: bool = False,
     ) -> np.ndarray:
         """
@@ -1158,6 +1230,9 @@ class CmdStanGQ:
         and the sample consists of 4 chains with 1000 post-warmup draws,
         this function will return a numpy.ndarray with shape (4000,3,3).
 
+        This functionaltiy is also available via a shortcut using ``.`` -
+        writing ``fit.a`` is a synonym for ``fit.stan_variable("a")``
+
         :param var: variable name
 
         :param inc_warmup: When ``True`` and the warmup draws are present in
@@ -1171,12 +1246,14 @@ class CmdStanGQ:
         CmdStanMLE.stan_variable
         CmdStanVB.stan_variable
         """
-        if var is None:
-            raise ValueError('No variable name specified.')
         model_var_names = self.mcmc_sample.metadata.stan_vars_cols.keys()
         gq_var_names = self.metadata.stan_vars_cols.keys()
         if not (var in model_var_names or var in gq_var_names):
-            raise ValueError('Unknown variable name: {}'.format(var))
+            raise ValueError(
+                f'Unknown variable name: {var}\n'
+                'Available variables are '
+                + ", ".join(model_var_names | gq_var_names)
+            )
         if var not in gq_var_names:
             return self.mcmc_sample.stan_variable(var, inc_warmup=inc_warmup)
         else:  # is gq variable
