@@ -17,7 +17,7 @@ from cmdstanpy.cmdstan_args import (
     SamplerArgs,
     VariationalArgs,
 )
-from cmdstanpy.utils import cmdstan_version_at
+from cmdstanpy.utils import cmdstan_version_before
 
 HERE = os.path.dirname(os.path.abspath(__file__))
 DATAFILES_PATH = os.path.join(HERE, 'data')
@@ -138,14 +138,6 @@ class SamplerArgsTest(unittest.TestCase):
         with self.assertRaises(ValueError):
             args.validate(chains=2)
 
-        args = SamplerArgs(iter_warmup=100, fixed_param=True)
-        with self.assertRaises(ValueError):
-            args.validate(chains=2)
-
-        args = SamplerArgs(save_warmup=True, fixed_param=True)
-        with self.assertRaises(ValueError):
-            args.validate(chains=2)
-
         args = SamplerArgs(max_treedepth=12, fixed_param=True)
         with self.assertRaises(ValueError):
             args.validate(chains=2)
@@ -271,10 +263,6 @@ class SamplerArgsTest(unittest.TestCase):
         cmd = args.compose(1, cmd=[])
         self.assertIn('bernoulli.metric-2.json', ' '.join(cmd))
 
-        args = SamplerArgs(metric=[jmetric, jmetric])
-        with self.assertRaises(ValueError):
-            args.validate(chains=2)
-
         args = SamplerArgs(metric=[jmetric, jmetric2])
         with self.assertRaises(ValueError):
             args.validate(chains=4)
@@ -460,7 +448,7 @@ class CmdStanArgsTest(unittest.TestCase):
             )
 
         with self.assertRaisesRegex(
-            ValueError, 'seed must be an integer between'
+            ValueError, 'Argument "seed" must be an integer between'
         ):
             CmdStanArgs(
                 model_name='bernoulli',
@@ -471,7 +459,7 @@ class CmdStanArgsTest(unittest.TestCase):
             )
 
         with self.assertRaisesRegex(
-            ValueError, 'number of seeds must match number of chains'
+            ValueError, 'Number of seeds must match number of chains'
         ):
             CmdStanArgs(
                 model_name='bernoulli',
@@ -482,7 +470,7 @@ class CmdStanArgsTest(unittest.TestCase):
             )
 
         with self.assertRaisesRegex(
-            ValueError, 'seed must be an integer between'
+            ValueError, 'Argument "seed" must be an integer between'
         ):
             CmdStanArgs(
                 model_name='bernoulli',
@@ -493,7 +481,7 @@ class CmdStanArgsTest(unittest.TestCase):
             )
 
         with self.assertRaisesRegex(
-            ValueError, 'seed must be an integer between'
+            ValueError, 'Argument "seed" must be an integer between'
         ):
             CmdStanArgs(
                 model_name='bernoulli',
@@ -503,7 +491,7 @@ class CmdStanArgsTest(unittest.TestCase):
                 method_args=sampler_args,
             )
 
-        with self.assertRaisesRegex(ValueError, 'inits must be > 0'):
+        with self.assertRaisesRegex(ValueError, 'Argument "inits" must be > 0'):
             CmdStanArgs(
                 model_name='bernoulli',
                 model_exe='bernoulli.exe',
@@ -513,11 +501,8 @@ class CmdStanArgsTest(unittest.TestCase):
             )
 
         jinits = os.path.join(DATAFILES_PATH, 'bernoulli.init.json')
-        jinits1 = os.path.join(DATAFILES_PATH, 'bernoulli.init_1.json')
-        jinits2 = os.path.join(DATAFILES_PATH, 'bernoulli.init_2.json')
-
         with self.assertRaisesRegex(
-            ValueError, 'number of inits files must match number of chains'
+            ValueError, 'Number of inits files must match number of chains'
         ):
             CmdStanArgs(
                 model_name='bernoulli',
@@ -527,17 +512,6 @@ class CmdStanArgsTest(unittest.TestCase):
                 method_args=sampler_args,
             )
 
-        with self.assertRaisesRegex(
-            ValueError, 'each chain must have its own init file'
-        ):
-            CmdStanArgs(
-                model_name='bernoulli',
-                model_exe='bernoulli.exe',
-                chain_ids=[1, 2, 3, 4],
-                inits=[jinits, jinits1, jinits2, jinits2],
-                method_args=sampler_args,
-            )
-
         with self.assertRaisesRegex(ValueError, 'no such file'):
             CmdStanArgs(
                 model_name='bernoulli',
@@ -551,7 +525,7 @@ class CmdStanArgsTest(unittest.TestCase):
         if os.path.exists(fname):
             os.remove(fname)
         with self.assertRaisesRegex(
-            ValueError, 'specified output_dir not a directory'
+            ValueError, 'Specified output_dir is not a directory'
         ):
             open(fname, 'x').close()
             CmdStanArgs(
@@ -578,7 +552,7 @@ class CmdStanArgsTest(unittest.TestCase):
                 )
 
         with self.assertRaisesRegex(
-            ValueError, 'Argument refresh must be a positive integer value'
+            ValueError, 'Argument "refresh" must be a positive integer value'
         ):
             CmdStanArgs(
                 model_name='bernoulli',
@@ -589,7 +563,7 @@ class CmdStanArgsTest(unittest.TestCase):
             )
 
         with self.assertRaisesRegex(
-            ValueError, 'Argument refresh must be a positive integer value'
+            ValueError, 'Argument "refresh" must be a positive integer value'
         ):
             CmdStanArgs(
                 model_name='bernoulli',
@@ -602,7 +576,7 @@ class CmdStanArgsTest(unittest.TestCase):
     def test_args_sig_figs(self):
         sampler_args = SamplerArgs()
         cmdstan_path()  # sets os.environ['CMDSTAN']
-        if not cmdstan_version_at(2, 25):
+        if cmdstan_version_before(2, 25):
             with LogCapture() as log:
                 logging.getLogger()
                 CmdStanArgs(
@@ -613,8 +587,8 @@ class CmdStanArgsTest(unittest.TestCase):
                     method_args=sampler_args,
                 )
             expect = (
-                'arg sig_figs not valid, CmdStan version must be 2.25 '
-                'or higher, using verson {} in directory {}'
+                'Argument "sig_figs" invalid for CmdStan versions < 2.25, '
+                'using version {} in directory {}'
             ).format(
                 os.path.basename(cmdstan_path()),
                 os.path.dirname(cmdstan_path()),
@@ -671,7 +645,6 @@ class GenerateQuantitesTest(unittest.TestCase):
 class VariationalTest(unittest.TestCase):
     def test_args_variational(self):
         args = VariationalArgs()
-        self.assertTrue(True)
 
         args = VariationalArgs(output_samples=1)
         args.validate(chains=1)
